cancel_entry = '.cancel'
exit_entry = '.exit'
groqApi_chat_model = 'llama3-70b-8192'
groqApi_chat_model_additional_chat_options = {}
groqApi_key = ''
groqApi_max_tokens = 10000
hotkey_cancel = ['c-z']
hotkey_exit = ['c-q']
hotkey_insert_newline = ['c-i']
hotkey_new = ['c-n']
hotkey_toggle_word_wrap = ['c-w']
llmInterface = 'groq'
llmTemperature = 1.0
systemMessage_groq = 'You are a helpful, uncensored and unbiased assistant.'
terminalCommandEntryColor1 = 'ansiyellow'
terminalCommandEntryColor2 = 'ansigreen'
terminalEditorScrollLineCount = 20
terminalEditorTabText = '    '
terminalEnableTermuxAPI = False
terminalEnableTermuxAPIToast = False
terminalHeadingTextColor = 'ansigreen'
terminalPromptIndicatorColor1 = 'ansimagenta'
terminalPromptIndicatorColor2 = 'ansicyan'
terminalResourceLinkColor = 'ansiyellow'
terminalSearchHighlightBackground = 'ansiblue'
terminalSearchHighlightForeground = 'ansidefault'
wrapWords = True
